@@ -65,7 +65,9 @@ void Folder::clone(const Folder *that, std::shared_ptr<Folder> other)
     QList<Clone> clones({{that, other, nullptr}});
     while (!clones.isEmpty()) {
         const auto &clone = clones.takeLast();
+        qCDebug(FILELIGHT_LOG) << "cloning" << clone.source->m_name << clone.source << "into" << clone.target.get() << "parent" << clone.parent.get();
         for (const auto &file : clone.source->files) {
+            qCDebug(FILELIGHT_LOG) << "  " << file->displayName() << file->isFolder();
             if (file->isFolder()) {
                 auto folder = std::dynamic_pointer_cast<Folder>(file);
                 clones.append(Clone{folder.get(), std::make_shared<Folder>(folder->m_name.constData()), clone.target});
